Struct XxInputMethodManagerV2
pub struct XxInputMethodManagerV2 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
input method manager
The input method manager allows the client to become the input method on a chosen seat.
No more than one input method must be associated with any seat at any given time.
This interface has no events.
Implementations
impl XxInputMethodManagerV2
impl XxInputMethodManagerV2
pub fn get_input_method<U, D>(
&self,
seat: &WlSeat,
qh: &QueueHandle<D>,
udata: U,
) -> XxInputMethodV1
pub fn get_input_method<U, D>( &self, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> XxInputMethodV1
request an input method object
Request a new input xx_input_method_v1 object associated with a given seat.
pub fn get_positioner<U, D>(
&self,
qh: &QueueHandle<D>,
udata: U,
) -> XxInputPopupPositionerV1
pub fn get_positioner<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> XxInputPopupPositionerV1
create a positioner object
Create a positioner object. A positioner object is used to position surfaces relative to some parent surface. See the interface description and xdg_surface.get_popup for details.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the input method manager
Destroys the xx_input_method_manager_v2 object.
The xx_input_method_v1 objects originating from it remain valid.